@@ -1,7 +1,14 @@
+from typing import Optional, List
+
+from vkbottle_types.objects import (
+    DocsDocTypes,
+    MessagesAudioMessage,
+    MessagesGraffiti,
+    DocsDocAttachmentType,
+    DocsDoc,
+    BaseUploadServer,
+)
 from .base_response import BaseResponse
-from vkbottle_types.objects import messages, docs, base
-from typing import Optional, Any, List, Union
-import typing
 
 
 class AddResponse(BaseResponse):
@@ -36,29 +43,38 @@ class AddResponseModel(BaseResponse):
     id: Optional[int] = None
 
 
-GetByIdResponseModel = List["docs.Doc"]
+GetByIdResponseModel = List[DocsDoc]
 
 
 class GetTypesResponseModel(BaseResponse):
     count: Optional[int] = None
-    items: Optional[List["docs.DocTypes"]] = None
+    items: Optional[List["DocsDocTypes"]] = None
 
 
-GetUploadServerModel = Optional["base.UploadServer"]
+GetUploadServerModel = Optional[BaseUploadServer]
 
 
 class GetResponseModel(BaseResponse):
     count: Optional[int] = None
-    items: Optional[List["docs.Doc"]] = None
+    items: Optional[List["DocsDoc"]] = None
 
 
 class SaveResponseModel(BaseResponse):
-    type: Optional["docs.DocAttachmentType"] = None
-    audio_message: Optional["messages.AudioMessage"] = None
-    doc: Optional["docs.Doc"] = None
-    graffiti: Optional["messages.Graffiti"] = None
+    type: Optional["DocsDocAttachmentType"] = None
+    audio_message: Optional["MessagesAudioMessage"] = None
+    doc: Optional["DocsDoc"] = None
+    graffiti: Optional["MessagesGraffiti"] = None
 
 
 class SearchResponseModel(BaseResponse):
     count: Optional[int] = None
-    items: Optional[List["docs.Doc"]] = None
+    items: Optional[List["DocsDoc"]] = None
+
+
+AddResponse.update_forward_refs()
+GetByIdResponse.update_forward_refs()
+GetTypesResponse.update_forward_refs()
+GetUploadServer.update_forward_refs()
+GetResponse.update_forward_refs()
+SaveResponse.update_forward_refs()
+SearchResponse.update_forward_refs()
